@@ -1,5 +1,5 @@
 from django.views.decorators.clickjacking import xframe_options_exempt
-from django.conf.urls import url, include
+from django.urls import path, re_path, include
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
 from django.contrib.admin.views.decorators import staff_member_required
 from django.conf import settings
@@ -18,10 +18,10 @@ if apollo_settings.DOWNLOAD_REQUIRES_IS_STAFF:
     download_submissions_view = staff_member_required(download_submissions_view)
 
 urlpatterns = [
-    url(r'builder/', form_builder_view),
-    url(r'download/', download_submissions_view),
-    url(r'render/', xframe_options_exempt(NoScriptForm.as_view()), name='render_noscript'),
-    url(r'%s/' % os.path.join(apollo_settings.API_ROOT, apollo_settings.API_VERSION), include(api_urls))
+    re_path('builder/(.*/)?', form_builder_view),
+    path('download/', download_submissions_view),
+    path('render/', xframe_options_exempt(NoScriptForm.as_view()), name='render_noscript'),
+    path('%s/' % os.path.join(apollo_settings.API_ROOT, apollo_settings.API_VERSION), include(api_urls))
 ]
 
 if settings.DEBUG:
